@@ -25,7 +25,7 @@ import logging
 from dataclasses import field
 from typing import Any, Callable, ClassVar, Dict, Iterable, Optional, TypeVar
 
-from ....domains.materials import SMILES, validate_molecules
+from ....domains.materials import SMILES, MoleculeFormat, validate_molecules
 from ....exceptions import InvalidItem
 from ...core import AlgorithmConfiguration, GeneratorAlgorithm
 from ...registry import ApplicationsRegistry
@@ -164,7 +164,9 @@ class ReinventGenerator(AlgorithmConfiguration[str, str]):
         Returns:
             the validated SMILES.
         """
-        molecules, _ = validate_molecules(smiles_list=[item])
+        molecules, _ = validate_molecules(
+            pattern_list=[item], input_type=MoleculeFormat.smiles
+        )
 
         if molecules[0] is None:
             raise InvalidItem(
